summaryrefslogtreecommitdiffstats
path: root/SourceLevelDebugPkg/Include
diff options
context:
space:
mode:
Diffstat (limited to 'SourceLevelDebugPkg/Include')
-rw-r--r--SourceLevelDebugPkg/Include/Ia32/ProcessorContext.h2
-rw-r--r--SourceLevelDebugPkg/Include/TransferProtocol.h6
2 files changed, 4 insertions, 4 deletions
diff --git a/SourceLevelDebugPkg/Include/Ia32/ProcessorContext.h b/SourceLevelDebugPkg/Include/Ia32/ProcessorContext.h
index 71f596f285..2c5cf03cec 100644
--- a/SourceLevelDebugPkg/Include/Ia32/ProcessorContext.h
+++ b/SourceLevelDebugPkg/Include/Ia32/ProcessorContext.h
@@ -1,5 +1,5 @@
/** @file
- IA32/x64 architecture specific defintions needed by debug transfer protocol.It is only
+ IA32/x64 architecture specific definitions needed by debug transfer protocol.It is only
intended to be used by Debug related module implementation.
Copyright (c) 2010 - 2012, Intel Corporation. All rights reserved.<BR>
diff --git a/SourceLevelDebugPkg/Include/TransferProtocol.h b/SourceLevelDebugPkg/Include/TransferProtocol.h
index 3904ba27dc..154e74165e 100644
--- a/SourceLevelDebugPkg/Include/TransferProtocol.h
+++ b/SourceLevelDebugPkg/Include/TransferProtocol.h
@@ -1,5 +1,5 @@
/** @file
- Transfer protocol defintions used by debug agent and host. It is only
+ Transfer protocol definitions used by debug agent and host. It is only
intended to be used by Debug related module implementation.
Copyright (c) 2010 - 2017, Intel Corporation. All rights reserved.<BR>
@@ -140,7 +140,7 @@ typedef struct {
UINT64 StopAddress;
} DEBUG_DATA_RESPONSE_BREAK_CAUSE;
//
// Break type defintions for DEBUG_DATA_BREAK_CAUSE
//
#define DEBUG_DATA_BREAK_CAUSE_UNKNOWN 0
#define DEBUG_DATA_BREAK_CAUSE_HW_BREAKPOINT 1
@@ -160,7 +160,7 @@ typedef struct {
UINT8 CpuMode;
} DEBUG_DATA_RESPONSE_ARCH_MODE;
//
// Cpu architecture defintions for DEBUG_DATA_RESPONSE_ARCH_MODE
//
#define DEBUG_DATA_BREAK_CPU_ARCH_IA16 0
#define DEBUG_DATA_BREAK_CPU_ARCH_IA32 1
@@ -140,7 +140,7 @@ typedef struct {
} DEBUG_DATA_RESPONSE_BREAK_CAUSE;
//
-// Break type defintions for DEBUG_DATA_BREAK_CAUSE
+// Break type definitions for DEBUG_DATA_BREAK_CAUSE
//
#define DEBUG_DATA_BREAK_CAUSE_UNKNOWN 0
@@ -160,7 +160,7 @@ typedef struct {
} DEBUG_DATA_RESPONSE_ARCH_MODE;
//
-// Cpu architecture defintions for DEBUG_DATA_RESPONSE_ARCH_MODE
+// Cpu architecture definitions for DEBUG_DATA_RESPONSE_ARCH_MODE
//
#define DEBUG_DATA_BREAK_CPU_ARCH_IA16 0